==> igniteui-react-core-16.16.1.tgz: package/esm5/lib/DefinitionBaseDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { DataBindingEventArgsDescriptionMetadata } from "./DataBindingEventArgsDescriptionMetadata";
import { CellStyleRequestedEventArgsDescriptionMetadata } from "./CellStyleRequestedEventArgsDescriptionMetadata";
/**
 * @hidden
 */
var DefinitionBaseDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(DefinitionBaseDescriptionMetadata, _super);
    function DefinitionBaseDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    DefinitionBaseDescriptionMetadata.b = function (a) {
        if (DefinitionBaseDescriptionMetadata.a == null) {
            DefinitionBaseDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            DefinitionBaseDescriptionMetadata.c(DefinitionBaseDescriptionMetadata.a);
        }
        if (a.g(DefinitionBaseDescriptionMetadata.a)) {
            return;
        }
        a.s(DefinitionBaseDescriptionMetadata.a);
        DataBindingEventArgsDescriptionMetadata.d(a);
        CellStyleRequestedEventArgsDescriptionMetadata.d(a);
    };
    DefinitionBaseDescriptionMetadata.c = function (a) {
        a.item("Background", "Brush");
        a.item("Border", "Brush");
        a.item("ActivationBorder", "Brush");
        a.item("ErrorBorder", "Brush");
        a.item("ActualBorder", "Brush");
        a.item("BorderLeftWidth", "Number:int");
        a.item("BorderTopWidth", "Number:int");
        a.item("BorderRightWidth", "Number:int");
        a.item("BorderBottomWidth", "Number:int");
        a.item("ActivationBorderLeftWidth", "Number:int");
        a.item("ActivationBorderTopWidth", "Number:int");
        a.item("ActivationBorderRightWidth", "Number:int");
        a.item("ActivationBorderBottomWidth", "Number:int");
        a.item("ErrorBorderLeftWidth", "Number:int");
        a.item("ErrorBorderTopWidth", "Number:int");
        a.item("ErrorBorderRightWidth", "Number:int");
        a.item("ErrorBorderBottomWidth", "Number:int");
        a.item("ActualBackground", "Brush");
        a.item("ActualActivationBorder", "Brush");
        a.item("ActualErrorBorder", "Brush");
        a.item("StickyRowBackground", "Brush");
        a.item("ActualStickyRowBackground", "Brush");
        a.item("PinnedRowBackground", "Brush");
        a.item("ActualPinnedRowBackground", "Brush");
        a.item("LastStickyRowBackground", "Brush");
        a.item("ActualLastStickyRowBackground", "Brush");
        a.item("ContentOpacity", "Number:double");
        a.item("HorizontalAlignment", "ExportedType:string:CellContentHorizontalAlignment");
        a.item("HorizontalAlignment@names", "Left;Center;Right;Stretch;Auto");
        a.item("VerticalAlignment", "ExportedType:string:CellContentVerticalAlignment");
        a.item("VerticalAlignment@names", "Top;Center;Bottom;Stretch;Auto");
        a.item("LineBreakMode", "ExportedType:string:TextCellLineBreakMode");
        a.item("LineBreakMode@names", "Ellipsis;NoWrap;WordWrap;CharacterWrap");
        a.item("ActualLineBreakMode", "ExportedType:string:TextCellLineBreakMode");
        a.item("ActualLineBreakMode@names", "Ellipsis;NoWrap;WordWrap;CharacterWrap");
        a.item("TextColor", "Brush");
        a.item("ActualTextColor", "Brush");
        a.item("PinnedRowOpacity", "Number:double");
        a.item("ActualPinnedRowOpacity", "Number:double");
        a.item("FontFamily", "(w:FontFamily/FontFamilyTransform,xam:FontFamily,wf:FontFamily,web:textStyle/FontFamilyTransform)String");
        a.item("FontSize", "(w:FontSize,xam:FontSize,wf:FontSize,web:textStyle/FontSizeTransform)Number:double");
        a.item("FontStyle", "(w:FontStyle/FontStyleTransform,xam:FontFamily/FontStyleTransform,wf:FontFamily/FontStyleTransform,web:textStyle/FontStyleTransform)String");
        a.item("FontWeight", "(w:FontWeight/FontWeightTransform,xam:FontFamily/FontWeightTransform,wf:FontFamily/FontWeightTransform,web:textStyle/FontWeightTransform)String");
        a.item("DataBindingRef", "EventRef::dataBinding");
        a.item("DataBoundRef", "EventRef::dataBound");
        a.item("CellStyleKeyRequestedRef", "EventRef::cellStyleKeyRequested");
    };
    DefinitionBaseDescriptionMetadata.d = function (a) {
        DefinitionBaseDescriptionMetadata.b(a);
        a.t("DefinitionBase", DefinitionBaseDescriptionMetadata.a);
    };
    DefinitionBaseDescriptionMetadata.$t = markType(DefinitionBaseDescriptionMetadata, 'DefinitionBaseDescriptionMetadata');
    DefinitionBaseDescriptionMetadata.a = null;
    return DefinitionBaseDescriptionMetadata;
}(Base));
export { DefinitionBaseDescriptionMetadata };

==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/DefinitionBaseDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { DataBindingEventArgsDescriptionMetadata } from "./DataBindingEventArgsDescriptionMetadata";
import { CellStyleRequestedEventArgsDescriptionMetadata } from "./CellStyleRequestedEventArgsDescriptionMetadata";
/**
 * @hidden
 */
var DefinitionBaseDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(DefinitionBaseDescriptionMetadata, _super);
    function DefinitionBaseDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    DefinitionBaseDescriptionMetadata.b = function (a) {
        if (DefinitionBaseDescriptionMetadata.a == null) {
            DefinitionBaseDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            DefinitionBaseDescriptionMetadata.c(DefinitionBaseDescriptionMetadata.a);
        }
        if (a.j(DefinitionBaseDescriptionMetadata.a)) {
            return;
        }
        a.y(DefinitionBaseDescriptionMetadata.a);
        DataBindingEventArgsDescriptionMetadata.d(a);
        CellStyleRequestedEventArgsDescriptionMetadata.d(a);
    };
    DefinitionBaseDescriptionMetadata.c = function (a) {
        a.item("Background", "Brush");
        a.item("Border", "Brush");
        a.item("ActivationBorder", "Brush");
        a.item("ErrorBorder", "Brush");
        a.item("ActualBorder", "Brush");
        a.item("BorderLeftWidth", "Number:int");
        a.item("BorderTopWidth", "Number:int");
        a.item("BorderRightWidth", "Number:int");
        a.item("BorderBottomWidth", "Number:int");
        a.item("ActivationBorderLeftWidth", "Number:int");
        a.item("ActivationBorderTopWidth", "Number:int");
        a.item("ActivationBorderRightWidth", "Number:int");
        a.item("ActivationBorderBottomWidth", "Number:int");
        a.item("ErrorBorderLeftWidth", "Number:int");
        a.item("ErrorBorderTopWidth", "Number:int");
        a.item("ErrorBorderRightWidth", "Number:int");
        a.item("ErrorBorderBottomWidth", "Number:int");
        a.item("ActualBackground", "Brush");
        a.item("ActualActivationBorder", "Brush");
        a.item("ActualErrorBorder", "Brush");
        a.item("StickyRowBackground", "Brush");
        a.item("ActualStickyRowBackground", "Brush");
        a.item("PinnedRowBackground", "Brush");
        a.item("ActualPinnedRowBackground", "Brush");
        a.item("LastStickyRowBackground", "Brush");
        a.item("ActualLastStickyRowBackground", "Brush");
        a.item("ContentOpacity", "Number:double");
        a.item("HorizontalAlignment", "ExportedType:string:CellContentHorizontalAlignment");
        a.item("HorizontalAlignment@names", "Left;Center;Right;Stretch;Auto");
        a.item("VerticalAlignment", "ExportedType:string:CellContentVerticalAlignment");
        a.item("VerticalAlignment@names", "Top;Center;Bottom;Stretch;Auto");
        a.item("LineBreakMode", "ExportedType:string:TextCellLineBreakMode");
        a.item("LineBreakMode@names", "Ellipsis;NoWrap;WordWrap;CharacterWrap");
        a.item("ActualLineBreakMode", "ExportedType:string:TextCellLineBreakMode");
        a.item("ActualLineBreakMode@names", "Ellipsis;NoWrap;WordWrap;CharacterWrap");
        a.item("TextColor", "Brush");
        a.item("ActualTextColor", "Brush");
        a.item("PinnedRowOpacity", "Number:double");
        a.item("ActualPinnedRowOpacity", "Number:double");
        a.item("FontFamily", "(w:FontFamily/FontFamilyTransform,xam:FontFamily,wf:FontFamily,web:textStyle/FontFamilyTransform)String");
        a.item("FontSize", "(w:FontSize,xam:FontSize,wf:FontSize,web:textStyle/FontSizeTransform)Number:double");
        a.item("FontStyle", "(w:FontStyle/FontStyleTransform,xam:FontFamily/FontStyleTransform,wf:FontFamily/FontStyleTransform,web:textStyle/FontStyleTransform)String");
        a.item("FontWeight", "(w:FontWeight/FontWeightTransform,xam:FontFamily/FontWeightTransform,wf:FontFamily/FontWeightTransform,web:textStyle/FontWeightTransform)String");
        a.item("DataBindingRef", "EventRef::dataBinding");
        a.item("DataBoundRef", "EventRef::dataBound");
        a.item("CellStyleKeyRequestedRef", "EventRef::cellStyleKeyRequested");
    };
    DefinitionBaseDescriptionMetadata.d = function (a) {
        DefinitionBaseDescriptionMetadata.b(a);
        a.z("DefinitionBase", DefinitionBaseDescriptionMetadata.a);
    };
    DefinitionBaseDescriptionMetadata.$t = markType(DefinitionBaseDescriptionMetadata, 'DefinitionBaseDescriptionMetadata');
    DefinitionBaseDescriptionMetadata.a = null;
    return DefinitionBaseDescriptionMetadata;
}(Base));
export { DefinitionBaseDescriptionMetadata };
